fn remove_unmentioned_methods(krate: &mut TranslatedCrate)Expand description
Emulate the behavior of our lazy method translation scheme by removing default trait methods that aren’t usefully mentioned anywhere.
fn remove_unmentioned_methods(krate: &mut TranslatedCrate)Emulate the behavior of our lazy method translation scheme by removing default trait methods that aren’t usefully mentioned anywhere.