struct TargetGroup {
ids: SeqHashMap<TargetTriple, ItemId>,
}Expand description
A set of items that share the same base name and item kind. These are candidates for merging into a single cross-target item.
Fields
ids: SeqHashMap<TargetTriple, ItemId>Implementations
Sourceimpl TargetGroup
impl TargetGroup
Sourcefn canonical_id(&self) -> ItemId
fn canonical_id(&self) -> ItemId
Deterministically chosen representative id.
Sourcefn is_function_group(&self) -> bool
fn is_function_group(&self) -> bool
Whether this group is a group of function items.
Sourcefn decide_merge(
&self,
krate: &TranslatedCrate,
remap: &HashMap<ItemId, ItemId>,
) -> MergeDecision
fn decide_merge( &self, krate: &TranslatedCrate, remap: &HashMap<ItemId, ItemId>, ) -> MergeDecision
Compare the items of this group under the provided id mapping.
Sourcefn remap_entries<'a>(&'a self) -> impl Iterator<Item = (ItemId, ItemId)> + 'a
fn remap_entries<'a>(&'a self) -> impl Iterator<Item = (ItemId, ItemId)> + 'a
Yields (non_canonical_id, canonical_id) pairs for building an ID remap.
fn into_remap_entries(self) -> impl Iterator<Item = (ItemId, ItemId)>
Sourcefn build_facade_decl(
&self,
def_id: FunDeclId,
krate: &TranslatedCrate,
) -> FunDecl
fn build_facade_decl( &self, def_id: FunDeclId, krate: &TranslatedCrate, ) -> FunDecl
Build a façade FunDecl for a group of functions with matching signatures but different
bodies. The def_id is set to a placeholder and must be fixed up on insertion.