#[repr(transparent)]pub struct TargetGroupId {
_raw: usize,
}Fields
_raw: usizeImplementations
Sourceimpl TargetGroupId
impl TargetGroupId
Sourcepub const MAX_INDEX: usize
pub const MAX_INDEX: usize
If Self::CHECKS_MAX_INDEX is true, we’ll assert if trying to
produce a value larger than this in any of the ctors that don’t
have unchecked in their name.
Sourcepub const CHECKS_MAX_INDEX: bool
pub const CHECKS_MAX_INDEX: bool
Does this index type assert if asked to construct an index larger than MAX_INDEX?
const _ENSURE_RAW_IS_UNSIGNED: [(); 0]
Sourcepub fn from_foreign<F: Idx>(value: F) -> Self
pub fn from_foreign<F: Idx>(value: F) -> Self
Construct this index type from one in a different domain
Sourcepub const fn from_usize_unchecked(value: usize) -> Self
pub const fn from_usize_unchecked(value: usize) -> Self
Construct from a usize without any checks.
Sourcepub const fn from_raw_unchecked(raw: usize) -> Self
pub const fn from_raw_unchecked(raw: usize) -> Self
Construct from the underlying type without any checks.
Sourcepub fn from_usize(value: usize) -> Self
pub fn from_usize(value: usize) -> Self
Construct this index type from a usize.
Sourcepub fn check_index(v: usize)
pub fn check_index(v: usize)
Asserts v <= Self::MAX_INDEX unless Self::CHECKS_MAX_INDEX is false.